<?php

return [
    /*
    |--------------------------------------------------------------------------
    | Routing
    |--------------------------------------------------------------------------
    |
    | To avoid conflicts with your application Peek provides you a way to move
    | the base path to something unique to your application.
    |
    | As well if you want to provide other middleware to Peek like your own
    | authorization then this can be added the middleware array.
    |
    */
    'routing' => [
        'root' => 'peek',
        'middleware' => ['web'],
    ],

    /*
    |--------------------------------------------------------------------------
    | Environment Variables
    |--------------------------------------------------------------------------
    |
    | This allows you to control what sort of environments are banned from being
    | edited within Peek. By default we try to catch and keys, secrets or password
    | that are used in your application.
    |
    | The banned variables supports wildcards so you can add an asterisk * to make
    | the match fuzzy.
    |
    */
    'env_variables' => [
        'banned' => [
            '*_KEY',
            '*_PASSWORD',
            '*_SECRET',
        ],
    ],

    /*
    |--------------------------------------------------------------------------
    | Commands
    |--------------------------------------------------------------------------
    |
    | Similar to the environment variables here you can specify commands that
    | you don't want to appear in the command list.
    |
    | You just need to specify what you normally put after "php artisan" and
    | this supports the * wildcard if you want to cover a range of commands.
    |
    */
    'commands' => [
        'hidden' => [
            'make*',
            'serve',
            'key:generate',
            'ide-helper*',
            'queue:work',
            'down',
            'tinker',
            'app:name',
        ],
    ],
    /*
    |--------------------------------------------------------------------------
    | Dashboard Blocks
    |--------------------------------------------------------------------------
    |
    | These are all the blocks that will display on the dashboard. Each one
    | of these are instantiated using the container and the render() function
    | is called on them.
    |
    */
    'dashboard_blocks' => [
        \Drp\Peek\Blocks\Versions::class,
        \Drp\Peek\Blocks\Caching::class,
        \Drp\Peek\Blocks\PublicAccessCheck::class,
        \Drp\Peek\Blocks\OpCacheReset::class,
        \Drp\Peek\Blocks\Drivers::class,
        \Drp\Peek\Blocks\PhpSettings::class,
        \Drp\Peek\Blocks\Extensions::class,
    ],

    /*
    |--------------------------------------------------------------------------
    | Laravel Mix
    |--------------------------------------------------------------------------
    |
    | You might be using Laravel Mix to build your assets and putting versioning
    | on them. If you are it is recommended that you add mix.version(['public/vendor/peek/app.css']);
    | to your webpack file and then set this config to true.
    |
    | This will allow Peek to cache bust the stylesheets if they were ever to change.
    |
    */
    'using_mix' => false,
];
