<?php

namespace Drp\Peek\Http\Controllers\Opcache;

use Illuminate\Contracts\View\View;
use Illuminate\Routing\Controller;
use Illuminate\Support\Str;

class Index extends Controller
{
    public function __invoke(): View
    {
        $status = opcache_get_status(true);
        $directives = opcache_get_configuration()['directives'];
        $settings = array_map(function ($value, $key) {
            return [
                'name' => str_replace('opcache.', '', $key),
                'value' => $value,
            ];
        }, $directives, array_keys($directives));

        $scripts = collect($status['scripts'])
            ->filter(function ($script) {
                return Str::startsWith($script['full_path'], base_path());
            })
            ->map(function ($script) {
                $script['path'] = str_replace(base_path('') . '/', '', $script['full_path']);

                return $script;
            })
            ->sortBy(function ($script) {
                return $script['path'];
            });

        return view('peek::opcache.index', [
            'scripts' => $scripts,
            'settings' => $settings,
        ]);
    }
}
